# What's Changed

1. ✨ 新增: 支持接入钉钉 #643
2. ✨ 新增: 支持设置私聊是否需要唤醒前缀唤醒 [#735](https://github.com/Soulter/AstrBot/issues/735)
3.  🐛 修复: 无法正常保存插件的 list 类型配置 #737
4.  🐛 修复: 部分情况下使用 aiocqhttp 报错 int 不能与 str 进行 '+' 操作的问题